@@ -56,8 +56,8 @@ def parse_config():
                 print(f"Config file found in {cfg_file} directory.")
                 break
         else:
-            print(f"Config file not found in {cfg_file} directory.")
-            print(f"Checking next directory...")
+            # print(f"Config file not found in {cfg_file} directory.")
+            # print(f"Checking next directory...")
     if not config:
         admin_interface = "https://software-api-admin.robinradar.systems"
         doc_pages = "https://robinradar.atlassian.net/wiki/spaces/DEV/pages/284033095/Software+Deployment+API"
